HasPosition

Trait HasPosition 

pub trait HasPosition {
    // Required method
    fn position(&self) -> Position;

    // Provided method
    fn offset(&self) -> u32 { ... }
}
A trait for types that have a single, defined source position.

Required Methods

fn position(&self) -> Position

Returns the source position.

Provided Methods

fn offset(&self) -> u32

A convenience method to get the byte offset of the position.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl HasPosition for Position

Source

impl<T: HasSpan> HasPosition for T

A blanket implementation that allows any HasSpan type to also be treated as a HasPosition type, using the span’s start as its position.